
/*
  10/16/2014 www.parallax.com
  
  Measures eTape variable resistance output using a resistor-capacitor 
  circuit built on Board of Education Shield and Arduino Uno.
  The rcTime function measures the decay time in microseconds. Decay time will be inversely 
  proportional to the liquid level: lower output values mean higher liquid levels.  

  Read the eTape sensor datasheet for instructions on positioning and mounting
  the sensor in a container of fluid, and for the sensor's pin descriptions.

  Connect one eTape Rsense terminal to ground.
  Use a 100 or 220 ohm resistor to connect the other Rsense terminal to Digital Pin 3.
  Place a capacitor across the terminals. A 0.1 uF cap will give a lower resolution, 
  and a 1.0 mF cap will give a higher resolution. If using a polar 1.0 uF cap,
  watch the polarity: be sure to connect its (-) lead to the grounded eTape terminal,
  and its (+)lead to the terminal on Digital Pin 3.  
  
  Run the Serial Monitor to see the output.  
*/

void setup()                                 // Built-in initialization block
{

  Serial.begin(9600);                        // Set data rate to 9600 bps
}  
 
void loop()                                  // Main loop auto-repeats
{
  long eTape = rcTime(3);                    // Change digital pin used here
 
  Serial.print("eTape = ");                  // Display eTape label
  Serial.print(eTape);                       // Display eTape value
  Serial.println(" us");                     // Display eTape units + newline

  delay(1000);                               // 1 second delay
}
                                             // rcTime function at pin  
long rcTime(int pin)                         // ..returns decay time
{                                            
  pinMode(pin, OUTPUT);                      // Charge capacitor
  digitalWrite(pin, HIGH);                   // ..by setting pin ouput-high
  delay(10);                                  // ..for 10 ms
  pinMode(pin, INPUT);                       // Set pin to input
  digitalWrite(pin, LOW);                    // ..with no pullup
  long time  = micros();                     // Mark the time
  while(digitalRead(pin));                   // Wait for voltage < threshold
  time = micros() - time;                    // Calculate decay time
  return time;                               // Return decay time
}  
